@@ -3,7 +3,7 @@ Author: Israel Dryer
 License: MIT
 Copyright (c) 2021 Israel Dryer
 """
-from ttkbootstrap import Style, Colors, StylerTTK, ThemeSettings
+from ttkbootstrap import Style, Colors, StylerTTK, ThemeDefinition
 import tkinter as tk
 from tkinter.font import families
 from tkinter import ttk
@@ -23,7 +23,7 @@ class CreatorDesignWindow(tk.Toplevel):
     """
     An application for designing and saving user-defined themes for ttk / tkinter.
 
-    DEV NOTES: press the <Insert> key to save a screenshot to examples.
+    DEV NOTES: press the <Insert> key to save a screenshot to images.
     """
 
     def __init__(self, master):
@@ -32,8 +32,8 @@ class CreatorDesignWindow(tk.Toplevel):
         self.protocol('WM_DELETE_WINDOW', self.master.quit)
         self.geometry(f'938x602+{master.winfo_x()}+{master.winfo_y()}')
         self.style = self.master.style
-        self.fallback_colors = deepcopy(self.style.colors)
         self.theme_name = self.master.style.theme_use()
+        self.fallback_colors = deepcopy(self.style.colors)
         self.vars = {}
         self.setup()
         self.bind("<Insert>", self.get_bounding_box)
@@ -219,9 +219,9 @@ class CreatorDesignWindow(tk.Toplevel):
 
     def reset_theme(self):
         """
-        Reset all values and variable to the default theme (dark='superhero', light='lumen')
+        Reset all values and variable to the default theme (dark='superhero', light='flatly')
         """
-        self.style.theme_use(self.theme_name)
+        self.style.theme_use(themename=self.theme_name)
         self.reset_variables()
         self.reset_color_patches()
 
@@ -259,7 +259,6 @@ class CreatorDesignWindow(tk.Toplevel):
         :param mode: the mode of the trace observer
         """
         theme_id = uuid.uuid4()  # a unique (and temporary) identifier for the new theme
-
         try:
             colors = Colors(
                 primary=self.getvar('primary'),
@@ -279,10 +278,13 @@ class CreatorDesignWindow(tk.Toplevel):
             return
 
         try:
-            settings = ThemeSettings(name=theme_id, type=self.getvar('inputfg'), font=self.getvar('font'),
-                                     colors=colors)
-            self.new_style = StylerTTK(self.style, settings)
-            self.style.theme_use(theme_id)
+            definition = ThemeDefinition(
+                name=theme_id,
+                type=self.getvar('inputfg'),
+                font=self.getvar('font'),
+                colors=colors)
+            self.new_style = StylerTTK(self.style, definition)
+            self.style.theme_use(themename=theme_id)
         except Exception:
             return
         """
@@ -300,7 +302,7 @@ class CreatorDesignWindow(tk.Toplevel):
 
     def get_bounding_box(self, event):
         """
-        Take a screenshot of the current demo window and save to examples
+        Take a screenshot of the current demo window and save to images
         """
         # bounding box
         titlebar = 31
@@ -308,15 +310,14 @@ class CreatorDesignWindow(tk.Toplevel):
         y1 = self.winfo_rooty() - titlebar
         x2 = x1 + self.winfo_width() + 2
         y2 = y1 + self.winfo_height() + titlebar + 1
-
-        self.after_idle(self.save_screenshot, [x1, y1, x2, y2])
+        self.save_screenshot([x1, y1, x2, y2])
 
     def save_screenshot(self, bbox):
         # screenshot
         img = ImageGrab.grab(bbox=bbox)
 
         # image name
-        filename = f'examples/ttkcreator.png'
+        filename = f'docs/images/ttkcreator.png'
         print(filename)
         img.save(filename, 'png')
 
@@ -355,7 +356,7 @@ class EverythingBagel(ttk.Notebook):
         # Separator
         ttk.Separator(self.tab).pack(fill='x', padx=10)
 
-        # Widget examples
+        # Widget images
         widget_frame = ttk.Frame(self.tab, padding=15)
         widget_frame.pack(fill='both')
 
@@ -443,11 +444,12 @@ class CreatorBaseChooser(tk.Tk):
     def __init__(self):
         super().__init__()
         self.style = Style()
-        self.style.theme_use('lumen')
+        self.title('TTK Creator')
         self.geometry(f'938x602')
         self.frame = ttk.Frame(self)
         self.setup()
         self.eval('tk::PlaceWindow . center')
+        self.bind("<Insert>", self.get_bounding_box)
 
     def setup(self):
         self.frame.pack(fill='both', expand='yes')
@@ -465,13 +467,13 @@ class CreatorBaseChooser(tk.Tk):
 
     def create_dark_theme(self):
         """
-        Startup the design window with the 'lumen' theme
+        Startup the design window with the 'flatly' theme
         """
         valid_user_path = self.check_user_themes_path()
         if not valid_user_path:
             return
 
-        self.style.theme_use('superhero')
+        self.style.theme_use(themename='darkly')
         CreatorDesignWindow(self)
         self.withdraw()
 
@@ -486,6 +488,27 @@ class CreatorBaseChooser(tk.Tk):
         CreatorDesignWindow(self)
         self.withdraw()
 
+    def save_screenshot(self, bbox):
+        # screenshot
+        img = ImageGrab.grab(bbox=bbox)
+
+        # image name
+        filename = f'docs/images/ttkcreator-splash.png'
+        print(filename)
+        img.save(filename, 'png')
+
+    def get_bounding_box(self, event):
+        """
+        Take a screenshot of the current demo window and save to images
+        """
+        # bounding box
+        titlebar = 31
+        x1 = self.winfo_rootx() - 1
+        y1 = self.winfo_rooty() - titlebar
+        x2 = x1 + self.winfo_width() + 2
+        y2 = y1 + self.winfo_height() + titlebar + 1
+        self.save_screenshot([x1, y1, x2, y2])
+
     def check_user_themes_path(self):
         """
         If the user defined themes path does not exists, ask for one
